<?php
	class Collapsing_Filters_Module extends ET_Builder_Module{
		
		protected $module_credits = [
			'module_uri' => 'https://makeweb.com.au',
			'author' => 'MakeWeb',
			'author_uri' => 'https://makeweb.com.au',
		];
		
		public function init(){
			$this->name            	= 'Collapsing Filters';
			$this->version         	= '1.1.0';
			$this->slug            	= 'collapsing_filters';
			$this->fb_support      	= 'partial';
			$this->use_row_content 	= true;
			$this->decode_entities 	= true;
			$this->main_css_element = '%%order_class%%';
			$this->fullwidth 		= false;
			$this->child_slug      	= 'collapsing_filter';
			$this->child_item_text 	= esc_html__( 'Filter', 'et_builder' );
			$this->custom_css_fields = array();
		}

		public function get_advanced_fields_config(){
			$advanced_fields = [];
			$advanced_fields['animation'] = FALSE;
			$advanced_fields['background'] = [];
			$advanced_fields['fonts']['title'] = [
				'label' => "Product Title",
				'css' => [
					'main' => "{$this->main_css_element} .menu-title ",
				],
				'line_height' => [
					'default' => '1.2em',
				],
			];
			$advanced_fields['fonts']['price'] = [
				'label' => "Product Price",
				'css' => [
					'main' => "{$this->main_css_element} .menu-price ",
				],
				'line_height' => [
					'default' => '1.2em',
				],
			];
			$advanced_fields['fonts']['description'] = [
				'label' => "Product Description",
				'css' => [
					'main' => "{$this->main_css_element} .menu-text ",
				],
				'line_height' => [
					'default' => '1.2em',
				],
			];
			$advanced_fields['margin_padding'] = [
				'css' => [
					'padding' => "{$this->main_css_element}",
					'margin' => "{$this->main_css_element}",
				],
			];
			$advanced_fields['borders']['default'] = [
				'css' => array(
					'main' => array(
						'border_radii'        => '%%order_class%% ',
						'border_styles'       => '%%order_class%% ',
						'border_radii_hover'  => '%%order_class%% ',
						'border_styles_hover' => '%%order_class%% ',
					),
				),
			];
			$advanced_fields['borders']['separator'] = [
				'css' => array(
					'main' => array(
						'border_radii'        => '%%order_class%% .menu-text-separator',
						'border_styles'       => '%%order_class%% .menu-text-separator',
						'border_radii_hover'  => '%%order_class%% .menu-text-separator:hover',
						'border_styles_hover' => '%%order_class%% .menu-text-separator:hover',
					),
				),
				'label_prefix' => et_builder_i18n( 'Separator' ),
			];
			
			return $advanced_fields;
		}

		public function get_fields(){
			return [
				'filters_label' => [
					'label' => __('Filters Label', 'et_builder'),
					'type' => 'text',
					'default'  => "Refine",
				],
				'grid_id' => [
					'label' => __('Grid ID', 'et_builder'),
					'type' => 'text',
				],
				'breakpoint' => [
					'label' => __('Breakpoint', 'et_builder'),
					'type' => 'text',
					'default'  => "768",
				],
			];
		}

		public function render($atts, $content = NULL, $render_slug){
			$module_id = $this->props['module_id'];
			$module_class = $this->props['module_class'];
			$grid_id = $this->props['grid_id'];
			$breakpoint = $this->props['breakpoint'];
			$filters_label = $this->props['filters_label'];
			if($grid_id == ''){
				$grid_id = 1;
			}

			$output = sprintf(
				'<div %1$s class="%2$s colapsing_filters" data-breakpoint="%4$s">
				<div class="colapse_title"> %5$s </div>
				<div class="filter_wrap">
				%3$s 
				</div>
				</div>',
				$this->module_id(),
				$this->module_classname( $render_slug ),
				str_replace('grid="?"','grid="'.$grid_id.'"', $this->content ),
				$breakpoint,
				$filters_label
			);
			
			$current_directory_url = trailingslashit( wp_make_link_relative( get_template_directory_uri() . str_replace( get_template_directory(), '', __DIR__ ) ) );
			
			wp_enqueue_style( 'colapsingFilters', $current_directory_url . 'colapsingFilters.css', [], $this->version );
			wp_enqueue_script( 'colapsingFilters', $current_directory_url . 'colapsingFilters.js', [], $this->version );
			
			return do_shortcode( $output );
		}
	}
NEW Collapsing_Filters_Module;